@@ -5,9 +5,11 @@ pub mod context;
 pub mod file;
 pub mod fileinfo;
 pub mod filenode;
+pub mod hash;
 pub mod hooks;
 pub mod ident;
 pub mod import;
+pub mod interceptor;
 pub mod loc;
 pub mod media;
 pub mod node;
